@@ -12,6 +12,7 @@
 
 from apparmor import easyprof
 import apparmor
+import ctypes
 import errno
 import json
 import os
@@ -277,8 +278,8 @@ class ClickManifest(object):
         #    raise AppArmorException("package name '%s' in json doesn't " +
         #                            "match " % (field))
 
-        self.appname = click_json['name']
-        self.version = click_json['version']
+        self.app_pkgname = click_json['name']
+        self.app_version = click_json['version']
         if 'framework' in click_json:
             self.framework = click_json['framework']
         else:
@@ -386,15 +387,29 @@ class EasyprofProfile(object):
         self.profile['policy_version'] = version
 
 
+# Do this setup only once
+libnih_dbus = ctypes.cdll.LoadLibrary("libnih-dbus.so.1")
+nih_dbus_path = libnih_dbus.nih_dbus_path
+nih_dbus_path.restype = ctypes.c_char_p
+
+
+def dbus_path(p):
+    '''Convert a string to a DBus-compatible object path'''
+    s = str(nih_dbus_path(None, "", p.encode(), None), 'ascii')
+    if len(s) > 1:
+        s = s[1:]
+    return s
+
+
 def ubuntu_1310_transform(click_manifest):
     '''Ubuntu 13.10 SDK framework transformation function'''
     m = EasyprofManifest()
 
     for p in click_manifest.profiles:
         newp = EasyprofProfile(p)
-        newname = "%s_%s_%s" % (click_manifest.appname,
+        newname = "%s_%s_%s" % (click_manifest.app_pkgname,
                                 p,
-                                click_manifest.version)
+                                click_manifest.app_version)
 
         profile = click_manifest.profiles[p]
         for default in defaults_profile:
@@ -413,8 +428,9 @@ def ubuntu_1310_transform(click_manifest):
         else:
             newp.policyversion = "1.0"
 
-        newp.add_variable("APPNAME", click_manifest.appname)
-        newp.add_variable("APPVERSION", click_manifest.version)
+        newp.add_variable("APP_PKGNAME", click_manifest.app_pkgname)
+        newp.add_variable("APP_VERSION", click_manifest.app_version)
+        newp.add_variable("APP_ID_DBUS", dbus_path(newname))
         newp.add_variable("CLICK_DIR", click_manifest.click_dir)
 
         if 'policy_groups' in profile:
