@@ -187,6 +187,8 @@ class T(unittest.TestCase):
         cm = apparmor.click.ClickManifest(os.path.join(c.click_dir, n))
         easyprof_manifest = apparmor.click.transform(cm)
 
+        dbus_id = apparmor.click.dbus_path(nbase)
+
         expected = json.loads('''{
   "profiles": {
     "com.ubuntu.developer.username.myapp_sample-app_0.1": {
@@ -195,13 +197,14 @@ class T(unittest.TestCase):
       "policy_version": "1.0",
       "template": "ubuntu-sdk",
       "template_variables": {
-        "APPNAME": "com.ubuntu.developer.username.myapp",
-        "APPVERSION": "0.1",
+        "APP_ID_DBUS": "%s",
+        "APP_PKGNAME": "com.ubuntu.developer.username.myapp",
+        "APP_VERSION": "0.1",
         "CLICK_DIR": "%s"
       }
     }
   }
-}''' % (c.packages_tree))
+}''' % (dbus_id, c.packages_tree))
         self.assertEquals(expected, easyprof_manifest,
                           "Expected to get %s, got %s" %
                           (expected, easyprof_manifest))
@@ -233,6 +236,8 @@ class T(unittest.TestCase):
         cm = apparmor.click.ClickManifest(os.path.join(c.click_dir, n))
         easyprof_manifest = apparmor.click.transform(cm)
 
+        dbus_id = apparmor.click.dbus_path(nbase)
+
         expected = json.loads('''{
   "profiles": {
     "%s": {
@@ -241,13 +246,14 @@ class T(unittest.TestCase):
       "policy_version": "1.0",
       "template": "ubuntu-sdk",
       "template_variables": {
-        "APPNAME": "com.ubuntu.developer.username.myapp",
-        "APPVERSION": "0.3",
+        "APP_ID_DBUS": "%s",
+        "APP_PKGNAME": "com.ubuntu.developer.username.myapp",
+        "APP_VERSION": "0.3",
         "CLICK_DIR": "%s"
       }
     }
   }
-}''' % (nbase, c.packages_tree))
+}''' % (nbase, dbus_id, c.packages_tree))
         self.assertEquals(expected, easyprof_manifest,
                           "Expected to get %s, got %s" %
                           (expected, easyprof_manifest))
@@ -269,6 +275,8 @@ class T(unittest.TestCase):
         cm = apparmor.click.ClickManifest(os.path.join(c.click_dir, n))
         easyprof_manifest = apparmor.click.transform(cm)
 
+        dbus_id = apparmor.click.dbus_path(nbase)
+
         expected = json.loads('''{
   "profiles": {
     "%s": {
@@ -277,13 +285,14 @@ class T(unittest.TestCase):
       "policy_version": "1.0",
       "template": "ubuntu-sdk",
       "template_variables": {
-        "APPNAME": "com.ubuntu.developer.username.myapp",
-        "APPVERSION": "0.1",
+        "APP_ID_DBUS": "%s",
+        "APP_PKGNAME": "com.ubuntu.developer.username.myapp",
+        "APP_VERSION": "0.1",
         "CLICK_DIR": "%s"
       }
     }
   }
-}''' % (nbase, c.packages_tree))
+}''' % (nbase, dbus_id, c.packages_tree))
         self.assertEquals(expected, easyprof_manifest,
                           "Expected to get %s, got %s" %
                           (expected, easyprof_manifest))
@@ -324,6 +333,8 @@ class T(unittest.TestCase):
                                           "%s_sample-app_0.3.json" % package))
         easyprof_manifest = apparmor.click.transform(cm)
 
+        dbus_id = apparmor.click.dbus_path("%s_sample-app_0.3" % package)
+
         expected = json.loads('''{
   "profiles": {
     "%s_sample-app_0.3": {
@@ -332,13 +343,14 @@ class T(unittest.TestCase):
       "policy_version": "1.0",
       "template": "ubuntu-sdk",
       "template_variables": {
-        "APPNAME": "%s",
-        "APPVERSION": "0.3",
+        "APP_ID_DBUS": "%s",
+        "APP_PKGNAME": "%s",
+        "APP_VERSION": "0.3",
         "CLICK_DIR": "%s"
       }
     }
   }
-}''' % (package, package, c.packages_tree))
+}''' % (package, dbus_id, package, c.packages_tree))
         self.assertEquals(expected, easyprof_manifest,
                           "Expected to get %s, got %s" %
                           (expected, easyprof_manifest))
@@ -356,6 +368,8 @@ class T(unittest.TestCase):
                                           "%s_sample-app_0.3.json" % package))
         easyprof_manifest = apparmor.click.transform(cm)
 
+        dbus_id = apparmor.click.dbus_path("%s_sample-app_0.3" % package)
+
         expected = json.loads('''{
   "profiles": {
     "%s_sample-app_0.3": {
@@ -364,13 +378,14 @@ class T(unittest.TestCase):
       "policy_version": "1.0",
       "template": "ubuntu-sdk",
       "template_variables": {
-        "APPNAME": "%s",
-        "APPVERSION": "0.3",
+        "APP_ID_DBUS": "%s",
+        "APP_PKGNAME": "%s",
+        "APP_VERSION": "0.3",
         "CLICK_DIR": "%s"
       }
     }
   }
-}''' % (package, package, c.packages_tree))
+}''' % (package, dbus_id, package, c.packages_tree))
         self.assertEquals(expected, easyprof_manifest,
                           "Expected to get %s, got %s" % (expected,
                                                           easyprof_manifest))
@@ -394,6 +409,8 @@ class T(unittest.TestCase):
                                           (appname)))
         easyprof_manifest = apparmor.click.transform(cm)
 
+        dbus_id = apparmor.click.dbus_path("%s_0wnzered_0.99.9~123" % appname)
+
         expected = json.loads('''{
   "profiles": {
     "%s_0wnzered_0.99.9~123": {
@@ -402,13 +419,14 @@ class T(unittest.TestCase):
       "policy_version": "1.0",
       "template": "unconfined",
       "template_variables": {
-        "APPNAME": "%s",
-        "APPVERSION": "0.99.9~123",
+        "APP_ID_DBUS": "%s",
+        "APP_PKGNAME": "%s",
+        "APP_VERSION": "0.99.9~123",
         "CLICK_DIR": "%s"
       }
     }
   }
-}''' % (appname, appname, c.packages_tree))
+}''' % (appname, dbus_id, appname, c.packages_tree))
         self.assertEquals(expected, easyprof_manifest,
                           "Expected to get %s, got %s" % (expected,
                                                           easyprof_manifest))
